// Get the path of the currently running do-file
local do_file_path `c(pwd)'

// Change the working directory to the location of the do-file
cd "`do_file_path'"

clear

import delimited "`do_file_path'\local\tab_data\Bangladesh_Market_Fish_Full_Reference.csv", encoding(ISO-8859-2) 
keep species
egen tid=tag(species)
keep if tid==1
drop tid 
sort species
save "x1",replace

clear
* upazila period fish_number month day river questno year quantkg priceperkg species english_name minsal maxsal nameok meansal
import delimited "`do_file_path'\local\tab_data\Full_Catch_Record_With_Periods.csv"
sort species
save "x00",replace


clear
use "x1"
merge 1:n species using "x00"
keep if _merge==3
drop _merge
egen specid=group(fish_number)
egen upzid=group(upazila)
sort upazila month species
save "z0",replace


egen tid=tag(specid)
keep if tid==1
keep specid species english_name
sort specid
save "w0",replace

clear
use "z0"
gen count=1
collapse (sum) count,by(species)
rename count nobs
sort species
save "w1",replace


clear
import delimited "`do_file_path'\local\tab_data\Monthly Upazila Salinity.csv"
sort upazila month
by upazila: gen nsal1=msal[_n-1]
by upazila: gen nsal2=msal[_n-2]
by upazila: gen nsal3=msal[_n-3]
sort upazila month
save "z1",replace

merge 1:n upazila month using "z0"
drop _merge
sort upazila month species
drop if priceperkg==.
gen lprice=log(priceperkg)
gen lquant=log(quantkg)
gen lnsaln=log(msal)
gen lnsal1=log(nsal1)
gen lnsal2=log(nsal2)
gen lnsal3=log(nsal3)

tab species,gen(dsp)
tab month,gen(dmn)
tab upazila,gen(dup)

save "w2",replace
egen tid=tag(species)
keep if tid==1
drop tid
local nmx=_N

clear
use "w2"
reg lquant dup* i.specid##c.lnsaln 

esttab using "`do_file_path'\local\tab_data\Appendix_Table1_full_regression_output.csv",wide label replace


keep if _n==1
keep specid
gen b0=.
gen b1=.
gen spelast=.
save "z01",replace


clear
gen b0=.
gen specid=.
save "z00",replace

keep if _n==1

forval i=1/`nmx' {
di "`i'"
use "z01"
replace b0=_b[lnsaln]
replace b1=_b[`i'.specid#c.lnsaln]
replace spelast=b0+b1
replace specid=`i'
order specid b0 b1 spelast
append using "z00"
save "z00",replace
}

use "z00"
sort specid
merge 1:n specid using "w0"
drop _merge
sort species
merge 1:n species using "w1"
drop _merge
gsort spelast
outsheet species english_name nobs b0 b1 spelast using "`do_file_path'\local\tab_data\Appendix_Table1_Species_Salinity_Elasticities_3.csv",comma replace

erase "x00.dta"
erase "x1.dta"
erase "w0.dta"
erase "w1.dta"
erase "w2.dta"
erase"z0.dta"
erase"z1.dta"
erase"z00.dta"
erase"z01.dta"