// Get the path of the currently running do-file
local do_file_path `c(pwd)'

// Change the working directory to the location of the do-file
cd "`do_file_path'"

clear

import delimited "`do_file_path'\local\tab_data\Bangladesh_Market_Fish_Full_Reference.csv", encoding(ISO-8859-2) 
keep species
egen tid=tag(species)
keep if tid==1
drop tid 
sort species
save "x1",replace

clear
import delimited "`do_file_path'\local\tab_data\Full_Catch_Record_With_Periods.csv", encoding(ISO-8859-2) 
sort species
save "x00",replace

clear
use "x1"
merge 1:n species using "x00"
keep if _merge==3
drop _merge
egen specid=group(fish_number)
egen upzid=group(upazila)
sort upazila month species
save "z0",replace


egen tid=tag(specid)
keep if tid==1
keep specid species
sort specid
save "w0",replace

clear
use "z0"
gen count=1
collapse (sum) count,by(species)
rename count nobs
sort species
save "w1",replace


clear
import delimited "`do_file_path'\local\tab_data\Monthly Upazila Salinity.csv", encoding(ISO-8859-2) 
sort upazila month
by upazila: gen nsal1=msal[_n-1]
by upazila: gen nsal2=msal[_n-2]
by upazila: gen nsal3=msal[_n-3]
sort upazila month
save "z1",replace

merge 1:n upazila month using "z0"
drop _merge
sort upazila month species
drop if priceperkg==.
gen lprice=log(priceperkg)
gen lquant=log(quantkg)
gen lnsaln=log(msal)
gen lnsal1=log(nsal1)
gen lnsal2=log(nsal2)
gen lnsal3=log(nsal3)

tab species,gen(dsp)
tab month,gen(dmn)
tab upazila,gen(dup)

save "w2",replace
egen tid=tag(species)
keep if tid==1
drop tid
local nmx=_N

clear
use "w2"
keep if species=="Scomberomorus guttatus" & upazila=="Sarankhola"

scatter quantkg msal, ///              
               xtitle("Salinity (ppt)", size(small) margin(small)) ///
               ytitle("Catch Size (kg)", size(small) margin(small)) ///
               legend(off)

graph export "`do_file_path'\figures_rp\fig_09a_Scomberomorus_guttatus_Sarankhola_Salinity.png",replace


clear
use "w2"
keep if species=="Scomberomorus guttatus" & upazila=="Galachipa"

scatter quantkg msal, ///              
               xtitle("Salinity (ppt)", size(small) margin(small)) ///
               ytitle("Catch Size (kg)", size(small) margin(small)) ///
               legend(off)

graph export "`do_file_path'\figures_rp\fig_09b_Scomberomorus_guttatus_Galachipa_Salinity.png",replace

clear
use "w2"
keep if species=="Scomberomorus commerson" & upazila=="Mongla"

scatter quantkg msal, ///              
               xtitle("Salinity (ppt)", size(small) margin(small)) ///
               ytitle("Catch Size (kg)", size(small) margin(small)) ///
               legend(off)

graph export "`do_file_path'\figures_rp\fig_09c_Scomberomorus_commerson_Mongla_Salinity.png",replace

 
clear
use "w2"
keep if species=="Scomberomorus commerson" & upazila=="Khulna"

scatter quantkg msal, ///              
               xtitle("Salinity (ppt)", size(small) margin(small)) ///
               ytitle("Catch Size (kg)", size(small) margin(small)) ///
               legend(off)

graph export "`do_file_path'\figures_rp\fig_09d_Scomberomorus_commerson_Khulna_Salinity.png",replace

erase "w0.dta"
erase "w1.dta"
erase "w2.dta"
erase "x00.dta"
erase "x1.dta"
erase "z0.dta"
erase "z1.dta"