// Get the path of the currently running do-file
local do_file_path `c(pwd)'

// Change the working directory to the location of the do-file
cd "`do_file_path'"

clear

import delimited "`do_file_path'\local\tab_data\Bangladesh_Market_Fish_Full_Reference.csv", encoding(ISO-8859-2) 

keep species
egen tid=tag(species)
keep if tid==1
drop tid 
sort species
save "x1",replace

clear
* upazila period fish_number month day river questno year quantkg priceperkg species english_name minsal maxsal nameok meansal
import delimited "`do_file_path'\local\tab_data\Full_Catch_Record_With_Periods.csv", encoding(ISO-8859-2) 
sort species
save "x00",replace

clear
use "x1"
merge 1:n species using "x00"
keep if _merge==3
drop _merge
egen specid=group(fish_number)
egen upzid=group(upazila)
sort upazila month species
save "z0",replace


egen tid=tag(specid)
keep if tid==1
keep specid species
sort specid
save "w0",replace

clear
use "z0"
gen count=1
collapse (sum) count,by(species)
rename count nobs
sort species
save "w1",replace


clear
import delimited "`do_file_path'\local\tab_data\Monthly Upazila Salinity.csv", encoding(ISO-8859-2) 
sort upazila month
by upazila: gen nsal1=msal[_n-1]
by upazila: gen nsal2=msal[_n-2]
by upazila: gen nsal3=msal[_n-3]
sort upazila month
save "z1",replace

merge 1:n upazila month using "z0"
drop _merge
sort upazila month species
drop if priceperkg==.
gen lprice=log(priceperkg)
gen lquant=log(quantkg)
gen lnsaln=log(msal)
gen lnsal1=log(nsal1)
gen lnsal2=log(nsal2)
gen lnsal3=log(nsal3)

tab species,gen(dsp)
tab month,gen(dmn)
tab upazila,gen(dup)

save "w2",replace
collapse (mean) quantkg,by(upazila species msal)
sort upazila species msal
save "w3",replace

clear
use "w2"
reg lquant dup* i.specid##c.lnsaln 

save "z2",replace
egen tid=tag(upazila)
keep if tid==1
drop tid
keep upazila upzid dup*
save "y1",replace

clear
use "z2"
egen tid=tag(specid)
keep if tid==1
drop tid
keep species specid english_name
save "y2",replace

clear
import delimited "`do_file_path'\local\tab_data\Full Salinity Range.csv", encoding(ISO-8859-2) 
gen lnsaln=log(msal)
keep msal lnsaln
save "y3",replace
cross using "y2"
cross using "y1"
sort upazila species msal
save "y4",replace

predict plquant
gen pquant=exp(plquant)
keep upazila species english_name msal pquant
order upazila species english_name msal pquant
sort species 
save "y5",replace

clear
* species meanprice mprice
import delimited "`do_file_path'\local\tab_data\Species_Price_Class.csv", encoding(ISO-8859-2) 
sort species
merge 1:n species using "y5"
drop _merge
save "y6",replace

collapse (sum) pquant,by(msal mprice)
drop if msal==.

line pquant msal if mprice==1, xlabel(1(1)13, labsize(small)) ///
               ytitle("Catch Quantity (kg)", size(small) margin(small)) ///
               xtitle("Salinity (ppt)", size(small) margin(small)) ///
               legend(off)

graph export "`do_file_path'\figures_rp\Low-Price Quantity Salinity Response.png",replace


line pquant msal if mprice==2, xlabel(1(1)13, labsize(small)) ///
               ytitle("Catch Quantity (kg)", size(small) margin(small)) ///
               xtitle("Salinity (ppt)", size(small) margin(small)) ///
               legend(off)

graph export "`do_file_path'\figures_rp\Mid-Price Quantity Salinity Response.png",replace

line pquant msal if mprice==3, xlabel(1(1)13, labsize(small)) ///
               ytitle("Catch Quantity (kg)", size(small) margin(small)) ///
               xtitle("Salinity (ppt)", size(small) margin(small)) ///
               legend(off)

graph export "`do_file_path'\figures_rp\High-Price Quantity Salinity Response.png",replace

bysort mprice: egen minq=min(pquant)
bysort mprice: egen maxq=max(pquant)

egen tid=tag(mprice)
keep if tid==1
drop tid

keep mprice maxq minq

gen pctq=100*(minq-maxq)/maxq
outsheet using "`do_file_path'\local\tab_data\Min and Max Quantity by Price Class.csv",comma replace
 

 erase "w0.dta"
 erase "w1.dta"
 erase "w2.dta"
 erase "w3.dta"
 erase "x00.dta"
 erase "x1.dta"
 
 erase "y1.dta"
 erase "y2.dta"
 erase "y3.dta"
 erase "y4.dta"
 erase "y5.dta"
 erase "y6.dta"
 
 erase "z0.dta"
 erase "z1.dta"
 erase "z2.dta"