* Figure 12
// Get the path of the currently running do-file
local do_file_path `c(pwd)'

// Change the working directory to the location of the do-file
cd "`do_file_path'"

clear

import delimited "`do_file_path'\local\tab_data\Bangladesh_Market_Fish_Full_Reference.csv", encoding(ISO-8859-2) 
keep species
egen tid=tag(species)
keep if tid==1
drop tid 
sort species
save "x1",replace

clear
import delimited "`do_file_path'\local\tab_data\Full_Catch_Record_With_Periods.csv", encoding(ISO-8859-2) 
sort species
save "x00",replace

clear
use "x1"
merge 1:n species using "x00"
keep if _merge==3
drop _merge
egen specid=group(fish_number)
egen upzid=group(upazila)
sort upazila month species
save "z0",replace


egen tid=tag(specid)
keep if tid==1
keep specid species
sort specid
save "w0",replace

clear
use "z0"
gen count=1
collapse (sum) count,by(species)
rename count nobs
sort species
save "w1",replace


clear
import delimited "`do_file_path'\local\tab_data\Monthly Upazila Salinity.csv", encoding(ISO-8859-2) 
sort upazila month
by upazila: gen nsal1=msal[_n-1]
by upazila: gen nsal2=msal[_n-2]
by upazila: gen nsal3=msal[_n-3]
sort upazila month
save "z1",replace

merge 1:n upazila month using "z0"
drop _merge
sort upazila month species
drop if priceperkg==.
gen lprice=log(priceperkg)
gen lquant=log(quantkg)
gen lnsaln=log(msal)
gen lnsal1=log(nsal1)
gen lnsal2=log(nsal2)
gen lnsal3=log(nsal3)

gen quarter=ceil(month / 3)

tab species,gen(dsp)
tab month,gen(dmn)
tab upazila,gen(dup)
tab quarter,gen(dq)

replace lnsaln=lnsal2

sort species
save "w2",replace

clear
import delimited "`do_file_path'\local\tab_data\Species_Price_Class.csv"
keep species mprice
sort species
merge 1:n species using "w2"
drop _merge
save "w3",replace

keep if mprice==3
save "w4",replace
drop dsp*
tab species,gen(dsp)

replace lnsaln=lnsal2
reg lprice dup1 dup2 dup4 dup5 dsp* lnsaln

egen tid=tag(upazila)
keep if tid==1
drop tid
keep upazila upzid dup*
save "y1",replace

clear
use "w4"
egen tid=tag(specid)
keep if tid==1
drop tid
keep species specid english_name dsp*
save "y2",replace

clear
import delimited "`do_file_path'\local\tab_data\Full Salinity Range.csv"
gen lnsaln=log(msal)
keep msal lnsaln
save "y3",replace
cross using "y2"
cross using "y1"
sort upazila species msal
save "y4",replace

predict plprice
gen pprice=exp(plprice)
collapse (mean) pprice,by(msal)

line pprice msal, xlabel(1(1)13, labsize(small)) ///
               ytitle("Unit price (Taka/kg)", size(small) margin(small)) ///
               xtitle("Salinity (ppt)", size(small) margin(small)) ///
               legend(off)

graph export "`do_file_path'\figures_rp\High-Price Price Salinity Response.png",replace

egen pmax=max(pprice)
egen pmin=min(pprice)

keep if _n==1
gen dprice=100*(pmax-pmin)/pmin

erase "x1.dta"
erase "y1.dta"
erase "y2.dta"
erase "y3.dta"
erase "y4.dta"
erase "w0.dta"
erase "w1.dta"
erase "w2.dta"
erase "w3.dta"
erase "w4.dta"
erase "x00.dta"
erase "z0.dta"
erase "z1.dta"