
# creating bounding box
artisanal_fn <- file.path(wkdir,'local','geo_data','Artisanal_Locations.shp')
artisanal_sf <- st_read(artisanal_fn)
artisanal_sf3857 <- st_transform(artisanal_sf,3857)
artisanal_sf3857 <- artisanal_sf3857

### define  bbox
lon_min <- 89.25 # xmin
lon_max <- 90.50 # xmax
lat_min <- 21.75 # ymin
lat_max <- 22.75 # ymax

bgd_bbox <- st_bbox(st_sfc(st_point(c(lon_min, lat_min)), st_point(c(lon_max, lat_max))))

# 2. get overall rectangle for bbox
bb_rect <- data.frame(
  lat = c(lat_min, lat_max),
  lon = c(lon_min, lon_max)
) %>% 
  st_as_sf(coords = c("lon", "lat"), crs = 4326) %>% 
  st_bbox() %>% 
  st_as_sfc()
bgd_bbox3857 <- st_transform(bb_rect,"EPSG:3857")

# set defaults for the basemap, no token
basemaps::set_defaults(map_service = "carto", map_type = "voyager")

# map
p4basemap <- ggplot() + 
  basemap_gglayer(bgd_bbox3857) +
  scale_fill_identity() + 
  ggnewscale::new_scale_fill() + 
  geom_sf(data = artisanal_sf3857, 
          shape = 16,
          inherit.aes = FALSE, 
          fill = "red", 
          color = "#610000",
          alpha = .5, 
          size = 2) +
  geom_sf_text(data = artisanal_sf3857, 
               aes(label = upazila),   # Replace 'name' with the variable you want to label
               inherit.aes = FALSE, 
               size = 1.5,             # Adjust text size
               color = "#610000",      # Label text color
               fontface = "bold",    # Font style (optional)
               nudge_y = 2500,        # Adjust vertical position of labels (optional)
               nudge_x = 2500         # Adjust horizontal position of labels (optional)
  ) +
  coord_sf() +
  theme(
    axis.title.x = element_blank(),  # Remove x-axis title
    axis.title.y = element_blank(),  # Remove y-axis title
    axis.text.x = element_blank(),   # Remove x-axis text
    axis.text.y = element_blank(),   # Remove y-axis text
    axis.ticks = element_blank(),    # Remove axis ticks
    panel.background = element_blank(),  # Remove the grey background
    plot.background = element_blank(),   # Remove the overall plot background
    panel.grid.major = element_blank(), # Remove major grid lines
    panel.grid.minor = element_blank()  # Remove minor grid lines
  )

p4basemap_fn <- file.path(figdir,'fig_04_markets.png')
ggsave(p4basemap_fn, p4basemap, width = 4, height = 4)

